@@ -66,6 +66,7 @@
 #endif
 #include <sys/time.h>
 #include <getopt.h> /* GNU extension: long options */
+#include <sched.h>
 
 /* For debugging purposes */
 #include <mcheck.h>
@@ -108,6 +109,30 @@ int main(int argc, char *argv[]) {
   debug = DEBUG;
 #endif
 
+  /* only useful for yet to code separate audio thread
+     (rt only for audio thread!)
+  struct sched_param schedpar; // scheduler structure for priority
+  int priority_min, priority_max;
+
+  // linux realtime scheduling
+  if ((priority_min = sched_get_priority_min(SCHED_FIFO)) < 0) {
+    perror("Realtime scheduling setup");
+    exit(1);
+  }
+  if ((priority_max = sched_get_priority_max(SCHED_FIFO)) < 0) {
+    perror("Realtime scheduling setup");
+    exit(1);
+  }
+  schedpar.sched_priority = (priority_min + priority_max) / 2; // arbitrary
+  if (sched_setscheduler(0, SCHED_FIFO, &schedpar) < 0) {
+    perror("Activating realtime scheduler");
+  }
+  // give up root privileges
+  if (setuid(getuid()) < 0) {
+    perror("Giving up root privileges");
+  }
+  */
+
   /* first: GTK+ internal parsing of command line arguments */
   gtk_init(&argc, &argv);
 
