@@ -21,7 +21,7 @@ enum call_type_t {
 };
 
 void cid_toggle_cb(GtkWidget *widget, gpointer data, guint action);
-GtkWidget *cid_get(struct session_t *session);
+GtkWidget *cid_new(struct session_t *session);
 void cid_add_line(struct session_t *session,
 		  enum call_type_t ct, gchar *from, gchar *to);
 void cid_add_data(struct session_t *session, gchar *from);
