@@ -31,6 +31,7 @@
 #include "llcheck.h"
 #include "settings.h"
 #include "gtksettings.h"
+#include "controlpad.h"
 
 /* graphical symbols */
 #include "hangup.xpm"
@@ -363,6 +364,7 @@ GtkWidget *get_main_menu(GtkWidget *window, struct session_t *session) {
                             NULL,     cid_toggle_cb, 0,        "<CheckItem>" },
     { "/View/_Line Level Meters",
                             NULL,     llcheck_toggle_cb,0,     "<CheckItem>" },
+    { "/View/Control _Pad", NULL,     controlpad_toggle_cb,0,  "<CheckItem>" },
 
     { "/_Options",          NULL,     NULL,          0,        "<Branch>"    },
     { "/Options/_Settings", NULL,     gtksettings_cb,0,        NULL          },
@@ -390,6 +392,8 @@ GtkWidget *get_main_menu(GtkWidget *window, struct session_t *session) {
 				   "/View/Caller ID Monitor");
   session->llcheck_check_menu_item = gtk_item_factory_get_item(item_factory,
 				   "/View/Line Level Meters");
+  session->controlpad_check_menu_item = gtk_item_factory_get_item(item_factory,
+				   "/View/Control Pad");
   session->menuitem_settings = gtk_item_factory_get_item(item_factory,
 				   "/Options/Settings");
   session->menuitem_line_check = gtk_item_factory_get_item(item_factory,
@@ -400,6 +404,9 @@ GtkWidget *get_main_menu(GtkWidget *window, struct session_t *session) {
   gtk_check_menu_item_set_active(
     GTK_CHECK_MENU_ITEM(session->llcheck_check_menu_item),
     session->option_show_llcheck);
+  gtk_check_menu_item_set_active(
+    GTK_CHECK_MENU_ITEM(session->controlpad_check_menu_item),
+    session->option_show_controlpad);
   
   return gtk_item_factory_get_widget(item_factory, "<main>");
 }
@@ -541,7 +548,7 @@ int main_gtk(struct session_t *session) {
 
   /* the main window */
   session->main_window = main_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-  gtk_window_set_title(GTK_WINDOW(main_window), "ANT");
+  gtk_window_set_title(GTK_WINDOW(main_window), "ANT " VERSION);
 
   gtk_signal_connect(GTK_OBJECT(main_window), "delete_event",
 		     GTK_SIGNAL_FUNC(delete_event), (gpointer) session);
@@ -569,8 +576,11 @@ int main_gtk(struct session_t *session) {
   dialbox = get_dial_box(session);
   gtk_widget_show(dialbox);
 
+  /* key pad */
+  session->controlpad = controlpad_new(session); /* show later */
+  
   /* the caller id section */
-  cidbox = cid_get(session);
+  cidbox = cid_new(session); /* show later */
 
   /* status bar */
   session->status_bar = gtk_statusbar_new();
@@ -605,7 +615,6 @@ int main_gtk(struct session_t *session) {
   gtk_widget_modify_style(GTK_STATUSBAR(session->audio_warning)->label,
 			  rc_style);
   gtk_rc_style_unref(rc_style);
-
   gtk_box_pack_end(GTK_BOX(session->status_bar),
 		   session->audio_warning, FALSE, FALSE, 0);
   session->audio_context_id =
@@ -613,6 +622,23 @@ int main_gtk(struct session_t *session) {
 				 "audio");
   gtk_statusbar_push(GTK_STATUSBAR(session->audio_warning),
 		     session->audio_context_id, "");
+  /* mute warning inside status bar */
+  session->muted_warning = gtk_statusbar_new();
+  gdk_color_parse("#008000", &color);
+  rc_style = gtk_rc_style_new();
+  rc_style->fg[GTK_STATE_NORMAL] = color;
+  rc_style->color_flags[GTK_STATE_NORMAL] |= GTK_RC_FG;
+  gtk_widget_modify_style(GTK_STATUSBAR(session->muted_warning)->label,
+			  rc_style);
+  gtk_rc_style_unref(rc_style);
+  gtk_box_pack_end(GTK_BOX(session->status_bar),
+		   session->muted_warning, FALSE, FALSE, 0);
+  session->muted_context_id =
+    gtk_statusbar_get_context_id(GTK_STATUSBAR(session->muted_warning),
+				 "muted");
+  gtk_statusbar_push(GTK_STATUSBAR(session->muted_warning),
+		     session->muted_context_id, "MUTED");
+
   
   /* main menu bar */
   main_menu = get_main_menu(main_window, session); /* main menu */
@@ -621,14 +647,19 @@ int main_gtk(struct session_t *session) {
   /* pack items into main vbox (after main menu bar creation) */
   gtk_box_pack_start(GTK_BOX(main_vbox), main_menu, FALSE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(main_vbox), dialbox, FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(main_vbox), session->controlpad, FALSE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(main_vbox), cidbox, TRUE, TRUE, 0);
   gtk_box_pack_end(GTK_BOX(main_vbox), session->status_bar, FALSE, FALSE, 2);
 
   /* show items on demand */
-  if (GTK_CHECK_MENU_ITEM (session->cid_check_menu_item)->active)
+  if (GTK_CHECK_MENU_ITEM(session->controlpad_check_menu_item)->active)
+    gtk_widget_show(session->controlpad);
+  if (GTK_CHECK_MENU_ITEM(session->cid_check_menu_item)->active)
     gtk_widget_show(cidbox);
-  if (GTK_CHECK_MENU_ITEM (session->llcheck_check_menu_item)->active)
+  if (GTK_CHECK_MENU_ITEM(session->llcheck_check_menu_item)->active)
     gtk_widget_show(session->llcheck);
+  if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(session->mute_button)))
+    gtk_widget_show(session->muted_warning);
 
   /* show everything */
   gtk_widget_show(main_window);
