@@ -31,6 +31,7 @@
 #include "callerid.h"
 #include "llcheck.h"
 #include "settings.h"
+#include "fxgenerator.h"
 
 /*
  * This is our session. Currently just one globally.
@@ -187,6 +188,21 @@ int session_isdn_init(struct session_t *session) {
   return 0;
 }
 
+/*
+ * de-allocates memory used by audio buffers of session
+ * -> prepares de-initialization
+ * -> is part of session_audio_free()
+ */
+void session_audio_free(struct session_t *session) {
+  free(session->audio_inbuf);
+  free(session->audio_outbuf);
+
+  free(session->audio_LUT_in);
+  free(session->audio_LUT_out);
+  free(session->audio_LUT_generate);
+  free(session->audio_LUT_analyze);
+}
+
 /*
  * close audio device(s) and clean up (deallocate buffers)
  *
@@ -194,14 +210,7 @@ int session_isdn_init(struct session_t *session) {
  */
 int session_audio_deinit(struct session_t *session) {
   /* free allocated buffers */
-  
-  free(session->audio_inbuf);
-  free(session->audio_outbuf);
-  
-  free(session->audio_LUT_in);
-  free(session->audio_LUT_out);
-  free(session->audio_LUT_generate);
-  free(session->audio_LUT_analyze);
+  session_audio_free(session);
   
   /* close audio device(s) */
   if (debug)
@@ -269,11 +278,13 @@ int session_init(struct session_t *session,
   					       strdup(""));
   session->dial_number_history_maxlen = 10; /* config overrides this */
 
-  /* default: save options automatically (on exit) */
-  session->option_save_options = 1;
-  session->option_release_devices = 0;
+  /* defaults */
+  session->option_save_options = 1; /* save options automatically (on exit) */
+  session->option_release_devices = 1;
   session->option_show_llcheck = 1;
   session->option_show_callerid = 1;
+  session->option_show_controlpad = 1;
+  session->option_muted = 0;
 
   session->audio_device_name_in = strdup(audio_device_name_in);
   session->audio_device_name_out = strdup(audio_device_name_out);
@@ -301,6 +312,12 @@ int session_init(struct session_t *session,
     session->msns = strdup(DEFAULT_MSNS);
   }
 
+  /* other defaults */
+  session->dial_number_history_pointer = 0;
+  session->touchtone_countdown_isdn = 0;
+  session->touchtone_countdown_audio = 0;
+  session->touchtone_index = 0;
+
   /* setup audio and isdn */
   if (session_audio_init(session) < 0) return -1;
   if (session_isdn_init(session) < 0) return -1;
@@ -557,93 +574,16 @@ void session_start_conversation(struct session_t *session) {
  */
 void session_effect_callback(gpointer data, gint fd _U_,
 			     GdkInputCondition condition _U_) {
-#define RING_PERIOD 4
-#define RING_LENGTH 1.3
-#define RING_FREQUENCY 1300
-/* fade in/out reciprocal period: */
-#define RING_FADE_LENGTH 0.003
-#define RING_SHORT_PERIOD 0.044
-#define RING_SHORT_LENGTH (RING_SHORT_PERIOD / 2)
-
-#define RINGING_FREQUENCY 425
-
   struct session_t *session = (struct session_t *) data;
   int i;
-  unsigned char x;
-  double seconds; /* position in seconds                    */
-  double rest;    /* monitor the period in seconds modulo 4 */
-  double rest2;   /* monitor (short) sinus period           */
-  double factor;  /* envelope factor                        */
-  double factor2; /* envelope help factor (short periods)   */
+  unsigned char x; /* generated ulaw sample */
+  double seconds; /* position in seconds */
 
   /* fill buffer */
   i = 0;
   while (i < session->fragment_size_out) {
     seconds = (double)session->effect_pos / session->audio_speed_out;
-    switch(session->effect) {
-    case EFFECT_RING: /* somebody's calling */
-    case EFFECT_TEST: /* play test sound */
-
-      if (session->effect == EFFECT_RING) {
-	rest = fmod(seconds, RING_PERIOD);               /* 4 sec period */
-      } else {
-	rest = seconds;                                  /* infinite period */
-      }
-
-      rest2 = fmod(seconds, RING_SHORT_PERIOD);          /* short period */
-
-      if (rest < RING_FADE_LENGTH) { /* fade in */
-	factor = -cos(rest * M_PI / RING_FADE_LENGTH) / 2 + 0.5;
-      } else if (rest > RING_LENGTH - RING_FADE_LENGTH &&
-		 rest < RING_LENGTH) { /* fade out */
-	factor = -cos((RING_LENGTH - rest) * 2 * M_PI / (RING_FADE_LENGTH * 2))
-	  / 2 + 0.5;
-
-      } else if (rest >= RING_LENGTH) { /* pause */
-	factor = 0;
-      } else { /* (potential) beep */
-	factor = 1;
-      }
-
-      if (rest2 > RING_SHORT_PERIOD - 0.5 * RING_FADE_LENGTH) {
-	/* fade in short period (1/2) */
-	factor2 = -sin((RING_SHORT_PERIOD - rest2)
-		       * 2 * M_PI / (RING_FADE_LENGTH * 2)) / 2 + 0.5;
-      } else if (rest2 < 0.5 * RING_FADE_LENGTH) {
-	/* fade in short period (2/2) */
-	factor2 = sin(rest2 * 2 * M_PI / (RING_FADE_LENGTH * 2)) / 2 + 0.5;
-      } else if (rest2 > RING_SHORT_LENGTH - 0.5 * RING_FADE_LENGTH &&
-		 rest2 < RING_SHORT_LENGTH + 0.5 * RING_FADE_LENGTH) {
-	/* fade out short period */
-	factor2 = -sin((rest2 - RING_SHORT_LENGTH)
-		       * 2 * M_PI / (RING_FADE_LENGTH * 2)) / 2 + 0.5;
-
-      } else if (rest2 <= RING_SHORT_LENGTH) { /* just beep */
-	factor2 = 1;
-      } else {
-	factor2 = 0; /* short pause */
-      }
-
-      factor = factor * factor2;
-
-      x = session->audio_LUT_generate[
-	(int)(sin(seconds * 2 * M_PI * RING_FREQUENCY)
-	      * factor * 127.5 + 127.5)];
-      break;
-      
-    case EFFECT_RINGING: /* waiting for the other end to pick up the phone */
-      rest = fmod(seconds, 5);
-      if (rest >= 2 && rest < 3) {
-	x = session->audio_LUT_generate[ /* beep */
-	  (int)(sin(seconds * 2 * M_PI * RINGING_FREQUENCY) * 127.5 + 127.5)];
-      } else {
-	x = session->audio_LUT_generate[128]; /* pause */
-      }
-      break;
-    default:
-      fprintf(stderr, "session_effect_callback: Unknown effect.\n");
-      x = 0;
-    }
+    x = fxgenerate(session, session->effect, 0, seconds);
     if (session->audio_sample_size_out == 1) {
       session->audio_outbuf[i++] = session->audio_LUT_in[(int)x];
     } else { /* audio_sample_size == 2 */
@@ -752,6 +692,8 @@ int session_set_state(struct session_t *session, enum state_t state) {
   case STATE_CONVERSATION:
     if (session->effect != EFFECT_NONE)
       session_effect_stop(session);
+    session->touchtone_countdown_isdn = 0;
+    session->touchtone_countdown_audio = 0;
     break;
   case STATE_SERVICE:
     break;
@@ -763,7 +705,7 @@ int session_set_state(struct session_t *session, enum state_t state) {
   if (session->option_release_devices) {
     session_audio_notify(session,
 			 state == STATE_READY || state == STATE_RINGING_QUIET ?
-			 "AUDIO OFF" : "AUDIO ON");
+			 "Audio OFF" : "Audio ON");
   } else {
     session_audio_notify(session, "");
   }
@@ -935,7 +877,8 @@ void gdk_handle_audio_input(gpointer data, gint fd _U_,
     }
     if (session->aborted) { /* That's it! */
       
-      session_deinit_conversation(session, 1); /* 1 == let's hang up (I/O error) */
+      session_deinit_conversation(session, 1);
+        /* 1 == let's hang up (I/O error) */
       
       session_set_state(session, STATE_READY);
       cid_call_finished(session, NULL);
@@ -1076,17 +1019,6 @@ void gtk_handle_hang_up_button(GtkWidget *widget _U_, gpointer data) {
  * -> and redisplay in session->dial_number_box
  */
 static void session_history_normalize(struct session_t *session) {
-  /* remove leading blank line(s) if possible */
-  /*
-  while (g_list_length(session->dial_number_history) > 1 &&
-	 !strcmp(g_list_nth_data(session->dial_number_history, 0), "")) {
-    free(g_list_nth_data(session->dial_number_history, 0));
-    session->dial_number_history = g_list_remove_link(
-	    session->dial_number_history,
-	    g_list_first(session->dial_number_history));
-  }
-  */
-
   /* cut size if needed */
   while (g_list_length(session->dial_number_history) >
 	 session->dial_number_history_maxlen) {
