@@ -27,16 +27,17 @@ enum state_t {
   STATE_RINGING_QUIET,  /* same as above, audio off (device blocked) */
   STATE_DIALING,        /* we are dialing out */
   STATE_CONVERSATION,   /* we are talking */
-  STATE_SERVICE,        /* special mode (init, settings, llcheck, ...) */
+  STATE_SERVICE,        /* special mode (init, llcheck, ...) */
 
   STATE_LAST /* dummy to calculate size */
 };
 
 enum effect_t {
-  EFFECT_NONE,    /* nothing is played currently */
-  EFFECT_RING,    /* somebody's calling */
-  EFFECT_RINGING, /* waiting for the other end to pick up the phone */
-  EFFECT_TEST     /* play test sound (e.g. line level check) */
+  EFFECT_NONE,     /* nothing is played currently */
+  EFFECT_RING,     /* somebody's calling */
+  EFFECT_RINGING,  /* waiting for the other end to pick up the phone */
+  EFFECT_TEST,     /* play test sound (e.g. line level check) */
+  EFFECT_TOUCHTONE /* play a touchtone */
 };
 
 /*
@@ -110,6 +111,7 @@ struct session_t {
   GtkWidget *dial_number_box; /* the dial number combo box */
   GList *dial_number_history; /* the last called numbers */
   unsigned int dial_number_history_maxlen; /* how many numbers to remember */
+  unsigned int dial_number_history_pointer; /* which one to use next if req */
   GtkWidget *status_bar; /* the status bar */
   gint phone_context_id; /* a context for the status bar */
   GtkWidget *audio_warning; /* inside status bar */
@@ -123,6 +125,12 @@ struct session_t {
   gint gdk_isdn_input_tag; /* these tags are saved to later remove handlers */
   gint gdk_audio_input_tag;
   
+  GtkWidget *controlpad; /* key pad etc. */
+  GtkWidget *controlpad_check_menu_item; /* display state of control pad */
+  GtkWidget *mute_button; /* toggle button */
+  GtkWidget *muted_warning; /* show in status bar if muted */
+  gint muted_context_id; /* a context for the status bar */
+
   /* caller id related */
   GtkWidget *cid; /* the caller id widget itself (to show/hide) */
   GtkWidget *cid_check_menu_item; /* to handle state of cid monitor (show?) */
@@ -143,6 +151,9 @@ struct session_t {
   gint effect_tag; /* remove this callback after e.g. ringing */
   enum effect_t effect; /* which effect is currently been played? */
   unsigned int effect_pos; /* sample position in effect */
+  int touchtone_countdown_isdn;  /* number of samples yet to play */
+  int touchtone_countdown_audio;
+  int touchtone_index; /* which touchtone */
 
   /* phone specific */
   enum state_t state; /* which state we are currently in */
@@ -157,6 +168,8 @@ struct session_t {
   int option_release_devices; /* close sound devices while not needed */
   int option_show_llcheck;    /* show line level checks in main window  */
   int option_show_callerid;   /* show callerid part in main window */
+  int option_show_controlpad; /* show control pad (key pad etc.) */
+  int option_muted;           /* mute microphone (other party gets zeros) */
 };
 
 extern struct session_t session;
@@ -165,6 +178,8 @@ int session_set_state(struct session_t *session, enum state_t state);
 void session_io_handlers_start(struct session_t *session);
 void session_io_handlers_stop(struct session_t *session);
 int session_reset_audio(struct session_t *session);
+int session_audio_open(struct session_t *session);
+int session_audio_close(struct session_t *session);
 int session_audio_init(struct session_t *session);
 int session_audio_deinit(struct session_t *session);
 
@@ -172,6 +187,7 @@ int session_init(struct session_t *session,
 		 char *audio_device_name_in,
 		 char *audio_device_name_out,
 		 char *msn, char *msns);
+void session_audio_free(struct session_t *session);
 int session_deinit(struct session_t *session);
 
 void session_effect_start(struct session_t *session, enum effect_t kind);
