@@ -10,8 +10,12 @@
 #ifndef _ANT_UTIL_H
 #define _ANT_UTIL_H
 
+#include "config.h"
+
 /* regular GNU system includes */
-#include <sys/time.h>
+#ifdef HAVE_SYS_TIME_H
+  #include <sys/time.h>
+#endif
 #include <time.h>
 
 #define SHORT_INTERVAL 10000
